/* List of defines generated by configure. Included with preprocessor flag,
 * -include, to avoid long list of -D defines on the compile command-line.
 * Do not edit.
 */

#ifndef _MOZILLA_CONFIG_H_
#define _MOZILLA_CONFIG_H_

#define ATTRIBUTE_ALIGNED_MAX 64
#define BUILD_CTYPES 1
#define CROSS_COMPILE 1
#define D_INO d_ino
#define HAVE_DIRENT_H 1
#define HAVE_DLADDR 1
#define HAVE_FCHMOD 1
#define HAVE_FLOCKFILE 1
#define HAVE_GETOPT_H 1
#define HAVE_I18N_LC_MESSAGES 1
#define HAVE_INT16_T 1
#define HAVE_INT32_T 1
#define HAVE_INT64_T 1
#define HAVE_INTTYPES_H 1
#define HAVE_ISATTY 1
#define HAVE_LANGINFO_CODESET 1
#define HAVE_LCHOWN 1
#define HAVE_LOCALECONV 1
#define HAVE_LOCALTIME_R 1
#define HAVE_LSTAT64 1
#define HAVE_MEMMOVE 1
#define HAVE_MEMORY_H 1
#define HAVE_MMINTRIN_H 1
#define HAVE_NL_TYPES_H 1
#define HAVE_RANDOM 1
#define HAVE_RINT 1
#define HAVE_SETBUF 1
#define HAVE_SIGINFO_T 1
#define HAVE_SNPRINTF 1
#define HAVE_SSIZE_T 1
#define HAVE_STAT64 1
#define HAVE_STDINT_H 1
#define HAVE_STRERROR 1
#define HAVE_STRTOK_R 1
#define HAVE_ST_BLKSIZE 1
#define HAVE_SYS_CDEFS_H 1
#define HAVE_SYS_STATVFS_H 1
#define HAVE_UINT 1
#define HAVE_UINT64_T 1
#define HAVE_UNISTD_H 1
#define HAVE_VA_COPY 1
#define HAVE_VISIBILITY_ATTRIBUTE 1
#define HAVE_VISIBILITY_HIDDEN_ATTRIBUTE 1
#define HAVE_X11_XKBLIB_H 1
#define HAVE__UNWIND_BACKTRACE 1
#define HAVE___CXA_DEMANGLE 1
#define IBMBIDI 1
#define LIBJPEG_TURBO_X86_ASM 1
#define MALLOC_H <malloc/malloc.h>
#define MOZILLA_VERSION "6.0a2"
#define MOZILLA_VERSION_U 6.0a2
#define MOZ_APP_UA_NAME ""
#define MOZ_APP_UA_VERSION "6.0a2"
#define MOZ_BUILD_APP xulrunner
#define MOZ_CRASHREPORTER 1
#define MOZ_CRASHREPORTER_ENABLE_PERCENT 100
#define MOZ_CSS_ANIMATIONS 1
#define MOZ_DEBUG_SYMBOLS 1
#define MOZ_DISTRIBUTION_ID "org.mozilla"
#define MOZ_DLL_SUFFIX ".dylib"
#define MOZ_FEEDS 1
#define MOZ_INSTRUMENT_EVENT_LOOP 1
#define MOZ_LOGGING 1
#define MOZ_MATHML 1
#define MOZ_MEDIA 1
#define MOZ_MORKREADER 1
#define MOZ_OGG 1
#define MOZ_OMNIJAR 1
#define MOZ_PLACES 1
#define MOZ_PROFILELOCKING 1
#define MOZ_RDF 1
#define MOZ_SMIL 1
#define MOZ_STATIC_JS 1
#define MOZ_STORAGE 1
#define MOZ_SVG 1
#define MOZ_SYDNEYAUDIO 1
#define MOZ_TREE_CAIRO 1
#define MOZ_TREE_PIXMAN 1
#define MOZ_UA_BUILDID ""
#define MOZ_UA_FIREFOX_VERSION "6.0a2"
#define MOZ_UPDATER 1
#define MOZ_UPDATE_CHANNEL default
#define MOZ_URL_CLASSIFIER 1
#define MOZ_USER_DIR "Mozilla"
#define MOZ_VORBIS 1
#define MOZ_WAVE 1
#define MOZ_WEBM 1
#define MOZ_WIDGET_COCOA 1
#define MOZ_XTF 1
#define MOZ_XUL 1
#define MOZ_XULRUNNER 1
#define NO_X11 1
#define NS_ALWAYS_INLINE __attribute__((always_inline))
#define NS_ATTR_MALLOC __attribute__((malloc))
#define NS_NORETURN __attribute__((noreturn))
#define NS_PRINTING 1
#define NS_PRINT_PREVIEW 1
#define NS_WARN_UNUSED_RESULT __attribute__((warn_unused_result))
#define STDC_HEADERS 1
#define UNIX_ASYNC_DNS 1
#define VA_COPY va_copy
#define VPX_X86_ASM 1
#define XP_MACOSX 1
#define XP_UNIX 1
#define X_DISPLAY_MISSING 1

#endif /* _MOZILLA_CONFIG_H_ */

