@namespace url("http://www.mozilla.org/keymaster/gatekeeper/there.is.only.xul");

.scale-slider {
  -moz-appearance: scale-horizontal;
  background: url("chrome://global/skin/scale/scale-tray-horiz.gif") 0% 50% repeat-x;
  margin: 2px 4px;
  width: 100px;
}

.scale-slider[orient="vertical"]
{
  -moz-appearance: scale-vertical;
  background: url("chrome://global/skin/scale/scale-tray-vert.gif") 50% 0% repeat-y;
  margin: 4px 2px;
  width: auto;
  height: 100px;
}

.scale-thumb {
  -moz-appearance: scalethumb-horizontal;
  border: 2px solid;
  -moz-border-top-colors: ThreeDLightShadow ThreeDHighlight;
  -moz-border-right-colors: ThreeDDarkShadow ThreeDShadow;
  -moz-border-bottom-colors: ThreeDDarkShadow ThreeDShadow;
  -moz-border-left-colors: ThreeDLightShadow ThreeDHighlight;
  background-color: -moz-Dialog;
  min-width: 30px;
  min-height: 15px;
}

.scale-thumb[orient="vertical"] {
  -moz-appearance: scalethumb-vertical;
  min-width: 15px;
  min-height: 30px;
}

.scale-thumb[disabled="true"] {
  -moz-border-top-colors: ThreeDHighlight ThreeDLightShadow !important;
  -moz-border-right-colors: ThreeDDarkShadow ThreeDShadow !important;
  -moz-border-bottom-colors: ThreeDDarkShadow ThreeDShadow !important;
  -moz-border-left-colors: ThreeDHighlight ThreeDLightShadow !important;
}
